==> pmml-model-1.0.0-sources.jar: org/dmg/pmml/AssociationRule.java <==

package org.dmg.pmml;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="antecedent" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="consequent" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="support" use="required" type="{http://www.dmg.org/PMML-4_1}PROB-NUMBER" />
 *       &lt;attribute name="confidence" use="required" type="{http://www.dmg.org/PMML-4_1}PROB-NUMBER" />
 *       &lt;attribute name="lift" type="{http://www.w3.org/2001/XMLSchema}float" />
 *       &lt;attribute name="leverage" type="{http://www.w3.org/2001/XMLSchema}float" />
 *       &lt;attribute name="affinity" type="{http://www.dmg.org/PMML-4_1}PROB-NUMBER" />
 *       &lt;attribute name="id" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions"
})
@XmlRootElement(name = "AssociationRule")
public class AssociationRule
    extends PMMLObject
    implements Equals, HashCode
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlAttribute(name = "antecedent", required = true)
    protected String antecedent;
    @XmlAttribute(name = "consequent", required = true)
    protected String consequent;
    @XmlAttribute(name = "support", required = true)
    protected BigDecimal support;
    @XmlAttribute(name = "confidence", required = true)
    protected BigDecimal confidence;
    @XmlAttribute(name = "lift")
    protected Float lift;
    @XmlAttribute(name = "leverage")
    protected Float leverage;
    @XmlAttribute(name = "affinity")
    protected BigDecimal affinity;
    @XmlAttribute(name = "id")
    protected String id;

    @Deprecated
    public AssociationRule() {
        super();
    }

    public AssociationRule(final String antecedent, final String consequent, final BigDecimal support, final BigDecimal confidence) {
        super();
        this.antecedent = antecedent;
        this.consequent = consequent;
        this.support = support;
        this.confidence = confidence;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the antecedent property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAntecedent() {
        return antecedent;
    }

    /**
     * Sets the value of the antecedent property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAntecedent(String value) {
        this.antecedent = value;
    }

    /**
     * Gets the value of the consequent property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConsequent() {
        return consequent;
    }

    /**
     * Sets the value of the consequent property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConsequent(String value) {
        this.consequent = value;
    }

    /**
     * Gets the value of the support property.
     * 
     * @return
     *     possible object is
     *     {@link BigDecimal }
     *     
     */
    public BigDecimal getSupport() {
        return support;
    }

    /**
     * Sets the value of the support property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigDecimal }
     *     
     */
    public void setSupport(BigDecimal value) {
        this.support = value;
    }

    /**
     * Gets the value of the confidence property.
     * 
     * @return
     *     possible object is
     *     {@link BigDecimal }
     *     
     */
    public BigDecimal getConfidence() {
        return confidence;
    }

    /**
     * Sets the value of the confidence property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigDecimal }
     *     
     */
    public void setConfidence(BigDecimal value) {
        this.confidence = value;
    }

    /**
     * Gets the value of the lift property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public Float getLift() {
        return lift;
    }

    /**
     * Sets the value of the lift property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setLift(Float value) {
        this.lift = value;
    }

    /**
     * Gets the value of the leverage property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public Float getLeverage() {
        return leverage;
    }

    /**
     * Sets the value of the leverage property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setLeverage(Float value) {
        this.leverage = value;
    }

    /**
     * Gets the value of the affinity property.
     * 
     * @return
     *     possible object is
     *     {@link BigDecimal }
     *     
     */
    public BigDecimal getAffinity() {
        return affinity;
    }

    /**
     * Sets the value of the affinity property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigDecimal }
     *     
     */
    public void setAffinity(BigDecimal value) {
        this.affinity = value;
    }

    /**
     * Gets the value of the id property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Sets the value of the id property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof AssociationRule)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final AssociationRule that = ((AssociationRule) object);
        {
            List<Extension> lhsExtensions;
            lhsExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            List<Extension> rhsExtensions;
            rhsExtensions = (((that.extensions!= null)&&(!that.extensions.isEmpty()))?that.getExtensions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "extensions", lhsExtensions), LocatorUtils.property(thatLocator, "extensions", rhsExtensions), lhsExtensions, rhsExtensions)) {
                return false;
            }
        }
        {
            String lhsAntecedent;
            lhsAntecedent = this.getAntecedent();
            String rhsAntecedent;
            rhsAntecedent = that.getAntecedent();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "antecedent", lhsAntecedent), LocatorUtils.property(thatLocator, "antecedent", rhsAntecedent), lhsAntecedent, rhsAntecedent)) {
                return false;
            }
        }
        {
            String lhsConsequent;
            lhsConsequent = this.getConsequent();
            String rhsConsequent;
            rhsConsequent = that.getConsequent();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "consequent", lhsConsequent), LocatorUtils.property(thatLocator, "consequent", rhsConsequent), lhsConsequent, rhsConsequent)) {
                return false;
            }
        }
        {
            BigDecimal lhsSupport;
            lhsSupport = this.getSupport();
            BigDecimal rhsSupport;
            rhsSupport = that.getSupport();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "support", lhsSupport), LocatorUtils.property(thatLocator, "support", rhsSupport), lhsSupport, rhsSupport)) {
                return false;
            }
        }
        {
            BigDecimal lhsConfidence;
            lhsConfidence = this.getConfidence();
            BigDecimal rhsConfidence;
            rhsConfidence = that.getConfidence();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "confidence", lhsConfidence), LocatorUtils.property(thatLocator, "confidence", rhsConfidence), lhsConfidence, rhsConfidence)) {
                return false;
            }
        }
        {
            Float lhsLift;
            lhsLift = this.getLift();
            Float rhsLift;
            rhsLift = that.getLift();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "lift", lhsLift), LocatorUtils.property(thatLocator, "lift", rhsLift), lhsLift, rhsLift)) {
                return false;
            }
        }
        {
            Float lhsLeverage;
            lhsLeverage = this.getLeverage();
            Float rhsLeverage;
            rhsLeverage = that.getLeverage();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "leverage", lhsLeverage), LocatorUtils.property(thatLocator, "leverage", rhsLeverage), lhsLeverage, rhsLeverage)) {
                return false;
            }
        }
        {
            BigDecimal lhsAffinity;
            lhsAffinity = this.getAffinity();
            BigDecimal rhsAffinity;
            rhsAffinity = that.getAffinity();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "affinity", lhsAffinity), LocatorUtils.property(thatLocator, "affinity", rhsAffinity), lhsAffinity, rhsAffinity)) {
                return false;
            }
        }
        {
            String lhsId;
            lhsId = this.getId();
            String rhsId;
            rhsId = that.getId();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "id", lhsId), LocatorUtils.property(thatLocator, "id", rhsId), lhsId, rhsId)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "extensions", theExtensions), currentHashCode, theExtensions);
        }
        {
            String theAntecedent;
            theAntecedent = this.getAntecedent();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "antecedent", theAntecedent), currentHashCode, theAntecedent);
        }
        {
            String theConsequent;
            theConsequent = this.getConsequent();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "consequent", theConsequent), currentHashCode, theConsequent);
        }
        {
            BigDecimal theSupport;
            theSupport = this.getSupport();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "support", theSupport), currentHashCode, theSupport);
        }
        {
            BigDecimal theConfidence;
            theConfidence = this.getConfidence();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "confidence", theConfidence), currentHashCode, theConfidence);
        }
        {
            Float theLift;
            theLift = this.getLift();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "lift", theLift), currentHashCode, theLift);
        }
        {
            Float theLeverage;
            theLeverage = this.getLeverage();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "leverage", theLeverage), currentHashCode, theLeverage);
        }
        {
            BigDecimal theAffinity;
            theAffinity = this.getAffinity();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "affinity", theAffinity), currentHashCode, theAffinity);
        }
        {
            String theId;
            theId = this.getId();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "id", theId), currentHashCode, theId);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

}

==> pmml-model-1.0.2-sources.jar: org/dmg/pmml/AssociationRule.java <==

package org.dmg.pmml;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="antecedent" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="consequent" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="support" use="required" type="{http://www.dmg.org/PMML-4_1}PROB-NUMBER" />
 *       &lt;attribute name="confidence" use="required" type="{http://www.dmg.org/PMML-4_1}PROB-NUMBER" />
 *       &lt;attribute name="lift" type="{http://www.w3.org/2001/XMLSchema}float" />
 *       &lt;attribute name="leverage" type="{http://www.w3.org/2001/XMLSchema}float" />
 *       &lt;attribute name="affinity" type="{http://www.dmg.org/PMML-4_1}PROB-NUMBER" />
 *       &lt;attribute name="id" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions"
})
@XmlRootElement(name = "AssociationRule")
public class AssociationRule
    extends PMMLObject
    implements Equals, HashCode, ToString
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlAttribute(name = "antecedent", required = true)
    protected String antecedent;
    @XmlAttribute(name = "consequent", required = true)
    protected String consequent;
    @XmlAttribute(name = "support", required = true)
    protected BigDecimal support;
    @XmlAttribute(name = "confidence", required = true)
    protected BigDecimal confidence;
    @XmlAttribute(name = "lift")
    protected Float lift;
    @XmlAttribute(name = "leverage")
    protected Float leverage;
    @XmlAttribute(name = "affinity")
    protected BigDecimal affinity;
    @XmlAttribute(name = "id")
    protected String id;

    @Deprecated
    public AssociationRule() {
        super();
    }

    public AssociationRule(final String antecedent, final String consequent, final BigDecimal support, final BigDecimal confidence) {
        super();
        this.antecedent = antecedent;
        this.consequent = consequent;
        this.support = support;
        this.confidence = confidence;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the antecedent property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAntecedent() {
        return antecedent;
    }

    /**
     * Sets the value of the antecedent property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAntecedent(String value) {
        this.antecedent = value;
    }

    /**
     * Gets the value of the consequent property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConsequent() {
        return consequent;
    }

    /**
     * Sets the value of the consequent property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConsequent(String value) {
        this.consequent = value;
    }

    /**
     * Gets the value of the support property.
     * 
     * @return
     *     possible object is
     *     {@link BigDecimal }
     *     
     */
    public BigDecimal getSupport() {
        return support;
    }

    /**
     * Sets the value of the support property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigDecimal }
     *     
     */
    public void setSupport(BigDecimal value) {
        this.support = value;
    }

    /**
     * Gets the value of the confidence property.
     * 
     * @return
     *     possible object is
     *     {@link BigDecimal }
     *     
     */
    public BigDecimal getConfidence() {
        return confidence;
    }

    /**
     * Sets the value of the confidence property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigDecimal }
     *     
     */
    public void setConfidence(BigDecimal value) {
        this.confidence = value;
    }

    /**
     * Gets the value of the lift property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public Float getLift() {
        return lift;
    }

    /**
     * Sets the value of the lift property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setLift(Float value) {
        this.lift = value;
    }

    /**
     * Gets the value of the leverage property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public Float getLeverage() {
        return leverage;
    }

    /**
     * Sets the value of the leverage property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setLeverage(Float value) {
        this.leverage = value;
    }

    /**
     * Gets the value of the affinity property.
     * 
     * @return
     *     possible object is
     *     {@link BigDecimal }
     *     
     */
    public BigDecimal getAffinity() {
        return affinity;
    }

    /**
     * Sets the value of the affinity property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigDecimal }
     *     
     */
    public void setAffinity(BigDecimal value) {
        this.affinity = value;
    }

    /**
     * Gets the value of the id property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Sets the value of the id property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof AssociationRule)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final AssociationRule that = ((AssociationRule) object);
        {
            List<Extension> lhsExtensions;
            lhsExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            List<Extension> rhsExtensions;
            rhsExtensions = (((that.extensions!= null)&&(!that.extensions.isEmpty()))?that.getExtensions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "extensions", lhsExtensions), LocatorUtils.property(thatLocator, "extensions", rhsExtensions), lhsExtensions, rhsExtensions)) {
                return false;
            }
        }
        {
            String lhsAntecedent;
            lhsAntecedent = this.getAntecedent();
            String rhsAntecedent;
            rhsAntecedent = that.getAntecedent();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "antecedent", lhsAntecedent), LocatorUtils.property(thatLocator, "antecedent", rhsAntecedent), lhsAntecedent, rhsAntecedent)) {
                return false;
            }
        }
        {
            String lhsConsequent;
            lhsConsequent = this.getConsequent();
            String rhsConsequent;
            rhsConsequent = that.getConsequent();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "consequent", lhsConsequent), LocatorUtils.property(thatLocator, "consequent", rhsConsequent), lhsConsequent, rhsConsequent)) {
                return false;
            }
        }
        {
            BigDecimal lhsSupport;
            lhsSupport = this.getSupport();
            BigDecimal rhsSupport;
            rhsSupport = that.getSupport();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "support", lhsSupport), LocatorUtils.property(thatLocator, "support", rhsSupport), lhsSupport, rhsSupport)) {
                return false;
            }
        }
        {
            BigDecimal lhsConfidence;
            lhsConfidence = this.getConfidence();
            BigDecimal rhsConfidence;
            rhsConfidence = that.getConfidence();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "confidence", lhsConfidence), LocatorUtils.property(thatLocator, "confidence", rhsConfidence), lhsConfidence, rhsConfidence)) {
                return false;
            }
        }
        {
            Float lhsLift;
            lhsLift = this.getLift();
            Float rhsLift;
            rhsLift = that.getLift();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "lift", lhsLift), LocatorUtils.property(thatLocator, "lift", rhsLift), lhsLift, rhsLift)) {
                return false;
            }
        }
        {
            Float lhsLeverage;
            lhsLeverage = this.getLeverage();
            Float rhsLeverage;
            rhsLeverage = that.getLeverage();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "leverage", lhsLeverage), LocatorUtils.property(thatLocator, "leverage", rhsLeverage), lhsLeverage, rhsLeverage)) {
                return false;
            }
        }
        {
            BigDecimal lhsAffinity;
            lhsAffinity = this.getAffinity();
            BigDecimal rhsAffinity;
            rhsAffinity = that.getAffinity();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "affinity", lhsAffinity), LocatorUtils.property(thatLocator, "affinity", rhsAffinity), lhsAffinity, rhsAffinity)) {
                return false;
            }
        }
        {
            String lhsId;
            lhsId = this.getId();
            String rhsId;
            rhsId = that.getId();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "id", lhsId), LocatorUtils.property(thatLocator, "id", rhsId), lhsId, rhsId)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "extensions", theExtensions), currentHashCode, theExtensions);
        }
        {
            String theAntecedent;
            theAntecedent = this.getAntecedent();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "antecedent", theAntecedent), currentHashCode, theAntecedent);
        }
        {
            String theConsequent;
            theConsequent = this.getConsequent();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "consequent", theConsequent), currentHashCode, theConsequent);
        }
        {
            BigDecimal theSupport;
            theSupport = this.getSupport();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "support", theSupport), currentHashCode, theSupport);
        }
        {
            BigDecimal theConfidence;
            theConfidence = this.getConfidence();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "confidence", theConfidence), currentHashCode, theConfidence);
        }
        {
            Float theLift;
            theLift = this.getLift();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "lift", theLift), currentHashCode, theLift);
        }
        {
            Float theLeverage;
            theLeverage = this.getLeverage();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "leverage", theLeverage), currentHashCode, theLeverage);
        }
        {
            BigDecimal theAffinity;
            theAffinity = this.getAffinity();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "affinity", theAffinity), currentHashCode, theAffinity);
        }
        {
            String theId;
            theId = this.getId();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "id", theId), currentHashCode, theId);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            strategy.appendField(locator, this, "extensions", buffer, theExtensions);
        }
        {
            String theAntecedent;
            theAntecedent = this.getAntecedent();
            strategy.appendField(locator, this, "antecedent", buffer, theAntecedent);
        }
        {
            String theConsequent;
            theConsequent = this.getConsequent();
            strategy.appendField(locator, this, "consequent", buffer, theConsequent);
        }
        {
            BigDecimal theSupport;
            theSupport = this.getSupport();
            strategy.appendField(locator, this, "support", buffer, theSupport);
        }
        {
            BigDecimal theConfidence;
            theConfidence = this.getConfidence();
            strategy.appendField(locator, this, "confidence", buffer, theConfidence);
        }
        {
            Float theLift;
            theLift = this.getLift();
            strategy.appendField(locator, this, "lift", buffer, theLift);
        }
        {
            Float theLeverage;
            theLeverage = this.getLeverage();
            strategy.appendField(locator, this, "leverage", buffer, theLeverage);
        }
        {
            BigDecimal theAffinity;
            theAffinity = this.getAffinity();
            strategy.appendField(locator, this, "affinity", buffer, theAffinity);
        }
        {
            String theId;
            theId = this.getId();
            strategy.appendField(locator, this, "id", buffer, theId);
        }
        return buffer;
    }

}
